'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _path = require('path');

var _path2 = _interopRequireDefault(_path);

var _loglevelColoredLevelPrefix = require('loglevel-colored-level-prefix');

var _loglevelColoredLevelPrefix2 = _interopRequireDefault(_loglevelColoredLevelPrefix);

var _findUp = require('find-up');

var _findUp2 = _interopRequireDefault(_findUp);

var _yargs = require('yargs');

var _yargs2 = _interopRequireDefault(_yargs);

var _commonTags = require('common-tags');

var _arrify = require('arrify');

var _arrify2 = _interopRequireDefault(_arrify);

var _camelcaseKeys = require('camelcase-keys');

var _camelcaseKeys2 = _interopRequireDefault(_camelcaseKeys);

var _chalk = require('chalk');

var _chalk2 = _interopRequireDefault(_chalk);

var _boolify = require('boolify');

var _boolify2 = _interopRequireDefault(_boolify);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var logger = (0, _loglevelColoredLevelPrefix2.default)({ prefix: 'prettier-eslint-cli' });

var parser = _yargs2.default.usage('Usage: $0 <globs>... [--option-1 option-1-value --option-2]').help('h').alias('h', 'help').version().options({
  write: {
    default: false,
    describe: 'Edit the file in-place (beware!)',
    type: 'boolean'
  },
  stdin: { default: false, describe: 'Read input via stdin', type: 'boolean' },
  'eslint-ignore': {
    default: true,
    type: 'boolean',
    describe: _commonTags.oneLine`
        Only format matching files even if
        they are not ignored by .eslintignore.
        (can use --no-eslint-ignore to disable this)
      `
  },
  'list-different': {
    default: false,
    type: 'boolean',
    describe: _commonTags.oneLine`
        Print filenames of files that are different
        from Prettier + Eslint formatting.
      `
  },
  eslintPath: {
    default: getPathInHostNodeModules('eslint'),
    describe: 'The path to the eslint module to use',
    coerce: coercePath
  },
  prettierPath: {
    describe: 'The path to the prettier module to use',
    default: getPathInHostNodeModules('prettier'),
    coerce: coercePath
  },
  ignore: {
    describe: _commonTags.oneLine`
        pattern(s) you wish to ignore
        (can be used multiple times
        and includes **/node_modules/** automatically)
      `,
    coerce: _arrify2.default
  },
  'log-level': {
    describe: 'The log level to use',
    choices: ['silent', 'error', 'warn', 'info', 'debug', 'trace'],
    alias: 'l',
    default: process.env.LOG_LEVEL || 'warn'
  },
  'prettier-last': {
    describe: 'Run prettier last',
    default: false,
    type: 'boolean'
  },
  prettier: {
    describe: _commonTags.oneLine`
        Prettier configuration options
        to be passed to prettier-eslint
        using dot-notation
      `
  }
}).coerce('prettier', function (config) {
  if (typeof config === 'object') {
    return (0, _boolify2.default)((0, _camelcaseKeys2.default)(config));
  } else {
    throw Error(_chalk2.default.red(_commonTags.oneLine`
            You should use dot-notation with
            the --prettier flag, for example, --prettier.singleQuote
          `));
  }
}).strict();

exports.default = parser;


function getPathInHostNodeModules(module) {
  logger.debug(`Looking for a local installation of the module "${module}"`);
  var modulePath = _findUp2.default.sync(`node_modules/${module}`);

  if (modulePath) {
    return modulePath;
  }
  logger.debug(_commonTags.oneLine`
      Local installation of "${module}" not found,
      looking again starting in "${__dirname}"
    `);

  return _findUp2.default.sync(`node_modules/${module}`, { cwd: __dirname });
}

function coercePath(input) {
  return _path2.default.isAbsolute(input) ? input : _path2.default.join(process.cwd(), input);
}